//
// Copyright (c) 2013, Red Hat Inc.
// Copyright (c) 2003, 2012, Oracle and/or its affiliates.
// All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/ad_aarch64.hpp"

//------------------Pipeline Methods-----------------------------------------
#ifndef PRODUCT
const char * Pipeline::stageName(uint s) {
  static const char * const _stage_names[] = {
    "undefined", "ISS", "EX1", "EX2", "WR"
  };

  return (s <= 4 ? _stage_names[s] : "???");
}
#endif

uint Pipeline::functional_unit_latency(uint start, const Pipeline *pred) const {
  // See if the functional units overlap
  uint mask = resourcesUsedExclusively() & pred->resourcesUsedExclusively();
  if (mask == 0)
    return (start);

  for (uint i = 0; i < pred->resourceUseCount(); i++) {
    const Pipeline_Use_Element *predUse = pred->resourceUseElement(i);
    if (predUse->multiple())
      continue;

    for (uint j = 0; j < resourceUseCount(); j++) {
      const Pipeline_Use_Element *currUse = resourceUseElement(j);
      if (currUse->multiple())
        continue;

      if (predUse->used() & currUse->used()) {
        Pipeline_Use_Cycle_Mask x = predUse->mask();
        Pipeline_Use_Cycle_Mask y = currUse->mask();

        for ( y <<= start; x.overlaps(y); start++ )
          y <<= 1;
      }
    }
  }

  // There is the potential for overlap
  return (start);
}

// The following two routines assume that the root Pipeline_Use entity
// consists of exactly 1 element for each functional unit
// start is relative to the current cycle; used for latency-based info
uint Pipeline_Use::full_latency(uint delay, const Pipeline_Use &pred) const {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      uint min_delay = 5;
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        uint curr_delay = delay;
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= curr_delay; x.overlaps(y); curr_delay++ )
            y <<= 1;
        }
        if (min_delay > curr_delay)
          min_delay = curr_delay;
      }
      if (delay < min_delay)
      delay = min_delay;
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= delay; x.overlaps(y); delay++ )
            y <<= 1;
        }
      }
    }
  }

  return (delay);
}

void Pipeline_Use::add_usage(const Pipeline_Use &pred) {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        if ( !predUse->_mask.overlaps(currUse->_mask) ) {
          currUse->_used |= (1 << j);
          _resources_used |= (1 << j);
          currUse->_mask.Or(predUse->_mask);
          break;
        }
      }
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        currUse->_used |= (1 << j);
        _resources_used |= (1 << j);
        currUse->_mask.Or(predUse->_mask);
      }
    }
  }
}

uint Pipeline::operand_latency(uint opnd, const Pipeline *pred) const {
  int const default_latency = 1;

  assert(this, "NULL pipeline info");
  assert(pred, "NULL predecessor pipline info");

  if (pred->hasFixedLatency())
    return (pred->fixedLatency());

  // If this is not an operand, then assume a dependence with 0 latency
  if (opnd > _read_stage_count)
    return (0);

  uint writeStage = pred->_write_stage;
  uint readStage  = _read_stages[opnd-1];

  if (writeStage == stage_undefined || readStage == stage_undefined)
    return (default_latency);

  int delta = writeStage - readStage;
  if (delta < 0) delta = 0;

  return (delta);
}

Pipeline_Use_Cycle_Mask operator&(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask & in2._mask);
}

Pipeline_Use_Cycle_Mask operator|(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask | in2._mask);
}

static const Pipeline pipeline_class_Zero_Instructions(0, 0, true, 0, 0, false, false, false, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

static const Pipeline pipeline_class_Unknown_Instructions(0, 0, true, 0, 0, false, true, true, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

const Pipeline_Use_Element Pipeline_Use::elaborated_elements[9] = {
  Pipeline_Use_Element(0, 0, 0, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 1, 1, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 2, 2, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 3, 3, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 4, 4, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 5, 5, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 6, 6, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 7, 7, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 8, 8, false, Pipeline_Use_Cycle_Mask(0))
};

const Pipeline_Use Pipeline_Use::elaborated_use(0, 0, 9, (Pipeline_Use_Element *)&elaborated_elements[0]);


// Pipeline Class "ialu_reg_reg"
static const enum machPipelineStages pipeline_reads_001[2] = {
  stage_EX1,
  stage_EX1 
};

static const enum machPipelineStages pipeline_res_stages_001[9] = {
  stage_ISS,       // INS0
  stage_ISS,       // INS1
  stage_EX2,       // INS01
  stage_EX2,       // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_001[9] = {
  1, // INS0
  1, // INS1
  1, // INS01
  1, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_001[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_001((uint)stage_EX2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_reg_reg_shift"
static const enum machPipelineStages pipeline_reads_002[3] = {
  stage_EX1,
  stage_ISS,
  stage_undefined 
};

static const Pipeline pipeline_class_002((uint)stage_EX2, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_reg_shift"
static const enum machPipelineStages pipeline_reads_003[1] = {
  stage_ISS 
};

static const Pipeline pipeline_class_003((uint)stage_EX2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_reg_reg_vshift"
static const enum machPipelineStages pipeline_reads_004[2] = {
  stage_ISS,
  stage_ISS 
};

static const enum machPipelineStages pipeline_res_stages_002[9] = {
  stage_ISS,       // INS0
  stage_ISS,       // INS1
  stage_EX1,       // INS01
  stage_EX1,       // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_002[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_004((uint)stage_EX1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_reg_reg_extr"
static const enum machPipelineStages pipeline_res_stages_003[9] = {
  stage_undefined, // INS0
  stage_ISS,       // INS1
  stage_EX1,       // INS01
  stage_EX1,       // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_002[9] = {
  0, // INS0
  1, // INS1
  1, // INS01
  1, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_003[2] = {
  Pipeline_Use_Element(0x002, 1, 1, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_005((uint)stage_EX2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x00e, 0x002, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg"
static const enum machPipelineStages pipeline_reads_005[1] = {
  stage_EX1 
};

static const Pipeline pipeline_class_006((uint)stage_EX2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_reg_imm"
static const Pipeline pipeline_class_007((uint)stage_EX2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_imm"
static const Pipeline pipeline_class_008((uint)stage_EX1, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "icmp_reg_reg"
static const Pipeline pipeline_class_009((uint)stage_EX2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "icmp_reg_imm"
static const Pipeline pipeline_class_010((uint)stage_EX2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "icond_none"
static const Pipeline pipeline_class_011((uint)stage_EX2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "icond_reg_reg"
static const enum machPipelineStages pipeline_reads_006[3] = {
  stage_EX1,
  stage_EX1,
  stage_EX1 
};

static const Pipeline pipeline_class_012((uint)stage_EX2, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_006,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "icond_reg"
static const Pipeline pipeline_class_013((uint)stage_EX2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "imul_reg_reg"
static const enum machPipelineStages pipeline_res_stages_004[9] = {
  stage_ISS,       // INS0
  stage_ISS,       // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_WR,        // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_003[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  1, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_004[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x010, 4, 4, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_014((uint)stage_WR, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "imac_reg_reg"
static const enum machPipelineStages pipeline_reads_007[3] = {
  stage_ISS,
  stage_ISS,
  stage_ISS 
};

static const Pipeline pipeline_class_015((uint)stage_WR, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "lmul_reg_reg"
static const Pipeline pipeline_class_016((uint)stage_WR, 2, true, 3, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "lmac_reg_reg"
static const Pipeline pipeline_class_017((uint)stage_WR, 3, true, 3, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "idiv_reg_reg"
static const enum machPipelineStages pipeline_res_stages_005[9] = {
  stage_ISS,       // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_WR,        // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_004[9] = {
  1, // INS0
  0, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  1, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_005[2] = {
  Pipeline_Use_Element(0x001, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x020, 5, 5, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_018((uint)stage_WR, 2, true, 8, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x021, 0x021, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "ldiv_reg_reg"
static const Pipeline pipeline_class_019((uint)stage_WR, 2, true, 16, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x021, 0x021, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "iload_prefetch"
static const enum machPipelineStages pipeline_res_stages_006[9] = {
  stage_ISS,       // INS0
  stage_ISS,       // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_WR,        // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_005[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  1, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_006[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_020((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "iload_reg_mem"
static const Pipeline pipeline_class_021((uint)stage_WR, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "iload_reg_reg"
static const Pipeline pipeline_class_022((uint)stage_WR, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "istore_mem"
static const Pipeline pipeline_class_023((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "istore_reg_mem"
static const enum machPipelineStages pipeline_reads_008[2] = {
  stage_EX2,
  stage_ISS 
};

static const Pipeline pipeline_class_024((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_008,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "istore_reg_reg"
static const enum machPipelineStages pipeline_reads_009[2] = {
  stage_ISS,
  stage_EX2 
};

static const Pipeline pipeline_class_025((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_009,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "pipe_branch"
static const enum machPipelineStages pipeline_res_stages_007[9] = {
  stage_ISS,       // INS0
  stage_ISS,       // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_EX1,       // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_006[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  1, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_007[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x040, 6, 6, false, Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_026((uint)stage_undefined, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "pipe_branch_cond"
static const Pipeline pipeline_class_027((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "pipe_cmp_branch"
static const Pipeline pipeline_class_028((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "pipe_serial"
static const uint pipeline_res_cycles_007[9] = {
  2, // INS0
  2, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  1, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_008[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000002)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_029((uint)stage_undefined, 0, true, 16, 1, false, false, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "pipe_slow"
static const Pipeline pipeline_class_030((uint)stage_undefined, 0, true, 16, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "pipe_class_empty"
static const enum machPipelineStages pipeline_res_stages_008[9] = {
  stage_undefined, // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_008[9] = {
  0, // INS0
  0, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline pipeline_class_031((uint)stage_undefined, 0, true, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_default"
static const Pipeline pipeline_class_032((uint)stage_undefined, 0, true, 2, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_compare"
static const Pipeline pipeline_class_033((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_memory"
static const Pipeline pipeline_class_034((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_call"
static const Pipeline pipeline_class_035((uint)stage_undefined, 0, true, 100, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

//------------------Inter-Instruction Latency--------------------------------
uint Node::latency(uint i) {
  uint j;
  // verify in legal range for inputs
  assert(i < len(), "index not in range");

  // verify input is not null
  Node *pred = in(i);
  if (!pred)
    return 0;

  if (pred->is_Proj())
    pred = pred->in(0);

  // if either node does not have pipeline info, use default
  const Pipeline *predpipe = pred->pipeline();
  assert(predpipe, "no predecessor pipeline info");

  if (predpipe->hasFixedLatency())
    return predpipe->fixedLatency();

  const Pipeline *currpipe = pipeline();
  assert(currpipe, "no pipeline info");

  if (!is_Mach())
    return 0;

  const MachNode *m = as_Mach();
  j = m->oper_input_base();
  if (i < j)
    return currpipe->functional_unit_latency(0, predpipe);

  // determine which operand this is in
  uint n = m->num_opnds();
  int delta = 0;

  uint k;
  for (k = 1; k < n; k++) {
    j += m->_opnds[k]->num_edges();
    if (i < j)
      break;
  }
  if (k < n)
    delta = currpipe->operand_latency(k,predpipe);

  return currpipe->functional_unit_latency(delta, predpipe);
}

// Descriptions for emitting different functional unit nops
void Bundle::initialize_nops(MachNode * nop_list[1], Compile *C) {
  nop_list[0] = (MachNode *) new (C) MachNopNode();
};

#ifndef PRODUCT
void Bundle::dump(outputStream *st) const {
  static const char * bundle_flags[] = {
    "",
    "use nop delay",
    "use unconditional delay",
    "use conditional delay",
    "used in conditional delay",
    "used in unconditional delay",
    "used in all conditional delays",
  };

  static const char *resource_names[9] = { "INS0", "INS1", "INS01", "ALU0", "ALU1", "ALU", "MAC", "DIV", "BRANCH" };

  bool needs_comma = false;

  if (_flags) {
    st->print("%s", bundle_flags[_flags]);
    needs_comma = true;
  };
  if (instr_count()) {
    st->print("%s%d instr%s", needs_comma ? ", " : "", instr_count(), instr_count() != 1 ? "s" : "");
    needs_comma = true;
  };
  uint r = resources_used();
  if (r) {
    st->print("%sresource%s:", needs_comma ? ", " : "", (r & (r-1)) != 0 ? "s" : "");
    for (uint i = 0; i < 9; i++)
      if ((r & (1 << i)) != 0)
        st->print(" %s", resource_names[i]);
    needs_comma = true;
  };
  st->print("\n");
}
#endif
const Pipeline *                         Node::pipeline_class() { return (&pipeline_class_Zero_Instructions); }
const Pipeline *                         Node::pipeline() const { return (&pipeline_class_Zero_Instructions); }

const Pipeline *                     MachNode::pipeline_class() { return (&pipeline_class_Unknown_Instructions); }
const Pipeline *                     MachNode::pipeline() const { return pipeline_class(); }

const Pipeline * MachNopNode::pipeline() const { return (&pipeline_class_031); }


const Pipeline *                        loadBNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadBNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                      loadB2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                      loadB2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                       loadUBNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                       loadUBNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                     loadUB2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                     loadUB2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadSNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadSNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                      loadS2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                      loadS2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                       loadUSNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                       loadUSNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                     loadUS2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                     loadUS2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadINode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadINode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                      loadI2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                      loadI2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                     loadUI2LNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                     loadUI2LNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadLNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadLNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                    loadRangeNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                    loadRangeNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadPNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadPNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadNNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                        loadNNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                    loadKlassNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                    loadKlassNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                   loadNKlassNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                   loadNKlassNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *                        loadFNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                        loadFNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                        loadDNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                        loadDNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                     loadConINode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                     loadConINode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                     loadConLNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                     loadConLNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                     loadConPNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                     loadConPNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                    loadConP0Node::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                    loadConP0Node::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                    loadConP1Node::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                    loadConP1Node::pipeline() const { return (&pipeline_class_008); }

const Pipeline *              loadConPollPageNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *              loadConPollPageNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *              loadByteMapBaseNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *              loadByteMapBaseNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                     loadConNNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                     loadConNNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                    loadConN0Node::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                    loadConN0Node::pipeline() const { return (&pipeline_class_008); }

const Pipeline *              loadConF_packedNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              loadConF_packedNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                     loadConFNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                     loadConFNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              loadConD_packedNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              loadConD_packedNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                     loadConDNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                     loadConDNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                  storeimmCM0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                  storeimmCM0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                       storeBNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                       storeBNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   storeimmB0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                   storeimmB0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                       storeCNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                       storeCNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   storeimmC0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                   storeimmC0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                       storeINode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                       storeINode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   storeimmI0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                   storeimmI0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                       storeLNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                       storeLNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   storeimmL0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                   storeimmL0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                       storePNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                       storePNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                   storeimmP0Node::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                   storeimmP0Node::pipeline() const { return (&pipeline_class_023); }

const Pipeline *   storeLastJavaPC_no_retaddrNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *   storeLastJavaPC_no_retaddrNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline * storeLastJavaPC_with_retaddrNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline * storeLastJavaPC_with_retaddrNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                       storeNNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                       storeNNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                   storeImmN0Node::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                   storeImmN0Node::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                       storeFNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                       storeFNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                       storeDNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                       storeDNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    prefetchrNode::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *                    prefetchrNode::pipeline() const { return (&pipeline_class_020); }

const Pipeline *                    prefetchwNode::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *                    prefetchwNode::pipeline() const { return (&pipeline_class_020); }

const Pipeline *                  prefetchntaNode::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *                  prefetchntaNode::pipeline() const { return (&pipeline_class_020); }

const Pipeline *            bytes_reverse_intNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            bytes_reverse_intNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           bytes_reverse_longNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           bytes_reverse_longNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline * bytes_reverse_unsigned_shortNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline * bytes_reverse_unsigned_shortNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          bytes_reverse_shortNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          bytes_reverse_shortNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           countLeadingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           countLeadingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           countLeadingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           countLeadingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          countTrailingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          countTrailingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          countTrailingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          countTrailingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               membar_acquireNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *               membar_acquireNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *               membar_releaseNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *               membar_releaseNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *              membar_volatileNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *              membar_volatileNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *  unnecessary_membar_volatileNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *  unnecessary_membar_volatileNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *            membar_storestoreNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *            membar_storestoreNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *          membar_acquire_lockNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *          membar_acquire_lockNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *          membar_release_lockNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *          membar_release_lockNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                      castX2PNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      castX2PNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      castP2XNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      castP2XNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      convP2INode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      convP2INode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      convN2INode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      convN2INode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                encodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                encodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *       encodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *       encodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                decodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                decodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *       decodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *       decodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                  checkCastPPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  checkCastPPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       castPPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       castPPNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       castIINode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       castIINode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  loadPLockedNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                  loadPLockedNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *            storePConditionalNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *            storePConditionalNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *            storeLConditionalNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *            storeLConditionalNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *            storeIConditionalNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *            storeIConditionalNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *              compareAndSwapINode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *              compareAndSwapINode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *              compareAndSwapLNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *              compareAndSwapLNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *              compareAndSwapPNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *              compareAndSwapPNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *              compareAndSwapNNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *              compareAndSwapNNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                 get_and_setINode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_setINode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 get_and_setLNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_setLNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 get_and_setNNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_setNNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 get_and_setPNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_setPNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 get_and_addLNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_addLNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *          get_and_addL_no_resNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *          get_and_addL_no_resNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                get_and_addLiNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                get_and_addLiNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *         get_and_addLi_no_resNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *         get_and_addLi_no_resNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                 get_and_addINode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                 get_and_addINode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *          get_and_addI_no_resNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *          get_and_addI_no_resNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                get_and_addIiNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                get_and_addIiNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *         get_and_addIi_no_resNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *         get_and_addIi_no_resNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                cmovI_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                cmovI_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovUI_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               cmovUI_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovI_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovI_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUI_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUI_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               cmovI_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovI_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUI_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUI_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *           cmovI_reg_zero_oneNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *           cmovI_reg_zero_oneNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *          cmovUI_reg_zero_oneNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *          cmovUI_reg_zero_oneNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                cmovL_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                cmovL_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovUL_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               cmovUL_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovL_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovL_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUL_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUL_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               cmovL_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovL_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUL_zero_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              cmovUL_zero_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                cmovP_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                cmovP_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovUP_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               cmovUP_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovP_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovP_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUP_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUP_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               cmovP_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovP_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUP_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUP_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                cmovN_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                cmovN_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovUN_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               cmovUN_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               cmovN_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovN_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUN_reg_zeroNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUN_reg_zeroNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               cmovN_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               cmovN_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              cmovUN_zero_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              cmovUN_zero_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                    cmovF_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                    cmovF_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                   cmovUF_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                   cmovUF_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    cmovD_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                    cmovD_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                   cmovUD_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                   cmovUD_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 addI_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 addI_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 addI_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 addI_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *             addI_reg_imm_i2lNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *             addI_reg_imm_i2lNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 addP_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 addP_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             addP_reg_reg_extNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             addP_reg_reg_extNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             addP_reg_reg_lslNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *             addP_reg_reg_lslNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       addP_reg_reg_ext_shiftNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       addP_reg_reg_ext_shiftNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                   lshift_extNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                   lshift_extNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                 addP_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 addP_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 addL_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 addL_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 addL_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 addL_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 subI_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 subI_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 subI_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 subI_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 subL_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 subL_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 subL_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 subL_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                     negI_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     negI_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                     negL_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     negL_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         mulINode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                         mulINode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                        smulINode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                        smulINode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                      smulI_0Node::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                      smulI_0Node::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                         mulLNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                         mulLNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  mulHiL_rRegNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  mulHiL_rRegNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                        maddINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        maddINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      maddI_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                      maddI_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        msubINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        msubINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        maddLNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        maddLNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                      maddL_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                      maddL_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                        msubLNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        msubLNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                         divINode::pipeline_class() { return (&pipeline_class_018); }
const Pipeline *                         divINode::pipeline() const { return (&pipeline_class_018); }

const Pipeline *                  signExtractNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                  signExtractNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                    div2RoundNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    div2RoundNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                  div2Round_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                  div2Round_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         divLNode::pipeline_class() { return (&pipeline_class_019); }
const Pipeline *                         divLNode::pipeline() const { return (&pipeline_class_019); }

const Pipeline *                 signExtractLNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                 signExtractLNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                   div2RoundLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                   div2RoundLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 div2RoundL_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 div2RoundL_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                         modINode::pipeline_class() { return (&pipeline_class_018); }
const Pipeline *                         modINode::pipeline() const { return (&pipeline_class_018); }

const Pipeline *                         modLNode::pipeline_class() { return (&pipeline_class_019); }
const Pipeline *                         modLNode::pipeline() const { return (&pipeline_class_019); }

const Pipeline *              lShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *              lShiftI_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *              lShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *              lShiftI_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *             urShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *             urShiftI_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *             urShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *             urShiftI_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *              rShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *              rShiftI_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *              rShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *              rShiftI_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *              lShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *              lShiftL_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *              lShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *              lShiftL_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *             urShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *             urShiftL_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *             urShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *             urShiftL_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *             urShiftP_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *             urShiftP_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *              rShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *              rShiftL_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *              rShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *              rShiftL_reg_immNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                 regL_not_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 regL_not_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 regI_not_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 regI_not_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             AndI_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AndI_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AndI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AndI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AndL_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AndL_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AndL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AndL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              OrI_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              OrI_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            OrI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            OrI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              OrL_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              OrL_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            OrL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            OrL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             XorI_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             XorI_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           XorI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           XorI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             XorL_reg_not_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             XorL_reg_not_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           XorL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           XorL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *     AndI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     AndI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   AndI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   AndI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     AndL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     AndL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   AndL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   AndL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      AndI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      AndI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    AndI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    AndI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      AndL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      AndL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    AndL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    AndL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      AndI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      AndI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    AndI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    AndI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      AndL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      AndL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    AndL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    AndL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     XorI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     XorI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorI_reg_URShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorI_reg_URShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorI_reg_URShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorI_reg_URShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     XorL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     XorL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorL_reg_URShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorL_reg_URShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *   XorL_reg_URShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *   XorL_reg_URShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      XorI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      XorI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_RShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_RShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_RShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_RShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      XorL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      XorL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_RShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_RShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_RShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_RShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      XorI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      XorI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_LShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_LShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorI_reg_LShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorI_reg_LShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      XorL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      XorL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_LShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_LShift_not_reg_1Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    XorL_reg_LShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    XorL_reg_LShift_not_reg_2Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      OrI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      OrI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    OrI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    OrI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *      OrL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *      OrL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *    OrL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *    OrL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       OrI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       OrI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     OrI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     OrI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       OrL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       OrL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     OrL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     OrL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       OrI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       OrI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     OrI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     OrI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       OrL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       OrL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *     OrL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *     OrL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         AndI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         AndI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       AndI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       AndI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         AndL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         AndL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       AndL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       AndL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AndI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AndI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AndI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AndI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AndL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AndL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AndL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AndL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AndI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AndI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AndI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AndI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AndL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AndL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AndL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AndL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         XorI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         XorI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       XorI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       XorI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         XorL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         XorL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       XorL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       XorL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          XorI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          XorI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        XorI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        XorI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          XorL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          XorL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        XorL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        XorL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          XorI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          XorI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        XorI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        XorI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          XorL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          XorL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        XorL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        XorL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          OrI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          OrI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        OrI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        OrI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          OrL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          OrL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        OrL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        OrL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *           OrI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *           OrI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         OrI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         OrI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *           OrL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *           OrL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         OrL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         OrL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *           OrI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *           OrI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         OrI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         OrI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *           OrL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *           OrL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         OrL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         OrL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         AddI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         AddI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       AddI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       AddI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         AddL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         AddL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *       AddL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *       AddL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AddI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AddI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AddI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AddI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AddL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AddL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AddL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AddL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AddI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AddI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AddI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AddI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          AddL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          AddL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *        AddL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *        AddL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         SubI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         SubI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *         SubL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *         SubL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          SubI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          SubI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          SubL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          SubL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          SubI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          SubI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *          SubL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *          SubL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                        sbfmLNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                        sbfmLNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                       sbfmwINode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                       sbfmwINode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                        ubfmLNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                        ubfmLNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                       ubfmwINode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                       ubfmwINode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                       ubfxwINode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                       ubfxwINode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                        ubfxLNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                        ubfxLNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                 ubfxIConvI2LNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                 ubfxIConvI2LNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                      extrOrLNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                      extrOrLNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                    extrOrL_0Node::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                    extrOrL_0Node::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                      extrOrINode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                      extrOrINode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                    extrOrI_0Node::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                    extrOrI_0Node::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                     extrAddLNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                     extrAddLNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                   extrAddL_0Node::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                   extrAddL_0Node::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                     extrAddINode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                     extrAddINode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                   extrAddI_0Node::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                   extrAddI_0Node::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                    rolL_rRegNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                    rolL_rRegNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                    rolI_rRegNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                    rolI_rRegNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                    rorL_rRegNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                    rorL_rRegNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                    rorI_rRegNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                    rorI_rRegNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                      AddExtINode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      AddExtINode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    AddExtI_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    AddExtI_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                      SubExtINode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                      SubExtINode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtI_sxthNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtI_sxthNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtI_sxth_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtI_sxth_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtI_sxtbNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtI_sxtbNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtI_sxtb_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtI_sxtb_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtI_uxtbNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtI_uxtbNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtI_uxtb_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtI_uxtb_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtL_sxthNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtL_sxthNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtL_sxth_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtL_sxth_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtL_sxtwNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtL_sxtwNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtL_sxtw_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtL_sxtw_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtL_sxtbNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtL_sxtbNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtL_sxtb_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtL_sxtb_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 AddExtL_uxtbNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 AddExtL_uxtbNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               AddExtL_uxtb_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               AddExtL_uxtb_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AddExtI_uxtb_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AddExtI_uxtb_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AddExtI_uxtb_and_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AddExtI_uxtb_and_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AddExtI_uxth_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AddExtI_uxth_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AddExtI_uxth_and_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AddExtI_uxth_and_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AddExtL_uxtb_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AddExtL_uxtb_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AddExtL_uxtb_and_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AddExtL_uxtb_and_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AddExtL_uxth_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AddExtL_uxth_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AddExtL_uxth_and_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AddExtL_uxth_and_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             AddExtL_uxtw_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             AddExtL_uxtw_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           AddExtL_uxtw_and_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           AddExtL_uxtw_and_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             SubExtI_uxtb_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             SubExtI_uxtb_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             SubExtI_uxth_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             SubExtI_uxth_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             SubExtL_uxtb_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             SubExtL_uxtb_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             SubExtL_uxth_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             SubExtL_uxth_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             SubExtL_uxtw_andNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             SubExtL_uxtw_andNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 addF_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 addF_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 addD_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 addD_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 subF_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 subF_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 subD_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 subD_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 mulF_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 mulF_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 mulD_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 mulD_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 divF_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 divF_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 divD_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 divD_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 negF_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 negF_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 negD_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                 negD_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                     absF_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                     absF_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                     absD_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                     absD_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    sqrtD_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                    sqrtD_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    sqrtF_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                    sqrtF_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                 andI_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 andI_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 andI_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 andI_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                  orI_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  orI_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  orI_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                  orI_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 xorI_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 xorI_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 xorI_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 xorI_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 andL_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 andL_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 andL_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 andL_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                  orL_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  orL_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  orL_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                  orL_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *                 xorL_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 xorL_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 xorL_reg_immNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *                 xorL_reg_immNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *              convI2L_reg_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *              convI2L_reg_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *             convUI2L_reg_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *             convUI2L_reg_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                  convL2I_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                  convL2I_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      convI2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      convI2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      convP2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      convP2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                  convD2F_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                  convD2F_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                  convF2D_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                  convF2D_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convF2I_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convF2I_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convF2L_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convF2L_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convI2F_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convI2F_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convL2F_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convL2F_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convD2I_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convD2I_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convD2L_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convD2L_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convI2D_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convI2D_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *              convL2D_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *              convL2D_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *            MoveF2I_stack_regNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *            MoveF2I_stack_regNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *            MoveI2F_stack_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *            MoveI2F_stack_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *            MoveD2L_stack_regNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *            MoveD2L_stack_regNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *            MoveL2D_stack_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *            MoveL2D_stack_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *            MoveF2I_reg_stackNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *            MoveF2I_reg_stackNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *            MoveI2F_reg_stackNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *            MoveI2F_reg_stackNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *            MoveD2L_reg_stackNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *            MoveD2L_reg_stackNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *            MoveL2D_reg_stackNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *            MoveL2D_reg_stackNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *              MoveF2I_reg_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *              MoveF2I_reg_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *              MoveI2F_reg_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *              MoveI2F_reg_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *              MoveD2L_reg_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *              MoveD2L_reg_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *              MoveL2D_reg_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *              MoveL2D_reg_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *           clearArray_reg_regNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *           clearArray_reg_regNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                compI_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                compI_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *              compI_reg_immI0Node::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *              compI_reg_immI0Node::pipeline() const { return (&pipeline_class_010); }

const Pipeline *         compI_reg_immIAddSubNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *         compI_reg_immIAddSubNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *               compI_reg_immINode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *               compI_reg_immINode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                compU_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                compU_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *              compU_reg_immI0Node::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *              compU_reg_immI0Node::pipeline() const { return (&pipeline_class_010); }

const Pipeline *         compU_reg_immIAddSubNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *         compU_reg_immIAddSubNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *               compU_reg_immINode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *               compU_reg_immINode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                compL_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                compL_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *              compL_reg_immI0Node::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *              compL_reg_immI0Node::pipeline() const { return (&pipeline_class_010); }

const Pipeline *         compL_reg_immLAddSubNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *         compL_reg_immLAddSubNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *               compL_reg_immLNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *               compL_reg_immLNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                compP_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                compP_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                compN_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                compN_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                    testP_regNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                    testP_regNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                    testN_regNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                    testN_regNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                compF_reg_regNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                compF_reg_regNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *               compF_reg_zeroNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *               compF_reg_zeroNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                compD_reg_regNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                compD_reg_regNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *               compD_reg_zeroNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *               compD_reg_zeroNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *               compF3_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *               compF3_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *               compD3_reg_regNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *               compD3_reg_regNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *             compF3_reg_immF0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *             compF3_reg_immF0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *             compD3_reg_immD0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *             compD3_reg_immD0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                cmpL3_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                cmpL3_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            cmpLTMask_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            cmpLTMask_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           cmpLTMask_reg_zeroNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *           cmpLTMask_reg_zeroNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                    minI_rRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    minI_rRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    maxI_rRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    maxI_rRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       branchNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                       branchNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                    branchConNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                    branchConNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                   branchConUNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                   branchConUNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *             cmpI_imm0_branchNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             cmpI_imm0_branchNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *             cmpL_imm0_branchNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             cmpL_imm0_branchNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *             cmpP_imm0_branchNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *             cmpP_imm0_branchNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                branchLoopEndNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                branchLoopEndNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *               branchLoopEndUNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *               branchLoopEndUNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                  cmpFastLockNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                  cmpFastLockNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                cmpFastUnlockNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                cmpFastUnlockNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                    safePointNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                    safePointNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *         CallStaticJavaDirectNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *         CallStaticJavaDirectNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *   CallStaticJavaDirectHandleNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *   CallStaticJavaDirectHandleNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *        CallDynamicJavaDirectNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *        CallDynamicJavaDirectNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *            CallRuntimeDirectNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *            CallRuntimeDirectNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *               CallLeafDirectNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *               CallLeafDirectNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *           CallLeafNoFPDirectNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *           CallLeafNoFPDirectNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *               TailCalljmpIndNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *               TailCalljmpIndNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                   TailjmpIndNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                   TailjmpIndNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *              CreateExceptionNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              CreateExceptionNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *             RethrowExceptionNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *             RethrowExceptionNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                          RetNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                          RetNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *           ShouldNotReachHereNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *           ShouldNotReachHereNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *          partialSubtypeCheckNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *          partialSubtypeCheckNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *    partialSubtypeCheckVsZeroNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *    partialSubtypeCheckVsZeroNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *               string_compareNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *               string_compareNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *               string_indexofNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *               string_indexofNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *           string_indexof_conNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *           string_indexof_conNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                string_equalsNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                string_equalsNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                 array_equalsNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                 array_equalsNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                     tlsLoadPNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     tlsLoadPNode::pipeline() const { return (&pipeline_class_031); }
// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
